from profile_python.profile import Profile

def main():
    profile = Profile()
    profile.run_app()

if __name__ == "__main__":
    main()
